==> jquery-fullscreen-1.1.30.tgz: jquery-fullscreen/README.md <==
# Installation
> `npm install --save @types/jquery-fullscreen`

# Summary
This package contains type definitions for jquery-fullscreen (https://github.com/kayahr/jquery-fullscreen-plugin).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-fullscreen.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-fullscreen/index.d.ts)
````ts
// Type definitions for jquery-fullscreen 1.1.5
// Project: https://github.com/kayahr/jquery-fullscreen-plugin
// Definitions by: Bruno Grieder <https://github.com/bgrieder>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery"/>

interface JQuery {
    /**
     * You can either switch the whole page or a single HTML element to fullscreen mode
     * This only works when the code was triggered by a user interaction (For example a onclick event on a button). Browsers don't allow entering fullscreen mode without user interaction.
     * Fullscreen mode is always exited via the document but this plugin allows it also via any HTML element. The owner document of the selected HTML element is used
     */
    fullScreen(fullScreen: boolean): JQuery | boolean;

    /**
     * The method returns the current fullscreen element (or true if browser doesn't support this) when fullscreen mode is active,
     * false if not active or null when the browser does not support fullscreen mode at all
     */
    fullScreen(): boolean;

    /**
     * The plugin provides another method for simple fullscreen mode toggling
     */
    toggleFullScreen(): JQuery | boolean;
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 20:36:37 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Bruno Grieder](https://github.com/bgrieder).

==> jquery-fullscreen-1.1.31.tgz: jquery-fullscreen/README.md <==
# Installation
> `npm install --save @types/jquery-fullscreen`

# Summary
This package contains type definitions for jquery-fullscreen (https://github.com/kayahr/jquery-fullscreen-plugin).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-fullscreen.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-fullscreen/index.d.ts)
````ts
/// <reference types="jquery"/>

interface JQuery {
    /**
     * You can either switch the whole page or a single HTML element to fullscreen mode
     * This only works when the code was triggered by a user interaction (For example a onclick event on a button). Browsers don't allow entering fullscreen mode without user interaction.
     * Fullscreen mode is always exited via the document but this plugin allows it also via any HTML element. The owner document of the selected HTML element is used
     */
    fullScreen(fullScreen: boolean): JQuery | boolean;

    /**
     * The method returns the current fullscreen element (or true if browser doesn't support this) when fullscreen mode is active,
     * false if not active or null when the browser does not support fullscreen mode at all
     */
    fullScreen(): boolean;

    /**
     * The plugin provides another method for simple fullscreen mode toggling
     */
    toggleFullScreen(): JQuery | boolean;
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 05:47:07 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)

# Credits
These definitions were written by [Bruno Grieder](https://github.com/bgrieder).
